==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/InlineHookBasePayload.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * InlineHookBasePayload
 */
@JsonPropertyOrder({ InlineHookBasePayload.JSON_PROPERTY_CLOUD_EVENT_VERSION,
        InlineHookBasePayload.JSON_PROPERTY_CONTENT_TYPE, InlineHookBasePayload.JSON_PROPERTY_EVENT_ID,
        InlineHookBasePayload.JSON_PROPERTY_EVENT_TIME, InlineHookBasePayload.JSON_PROPERTY_EVENT_TYPE_VERSION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class InlineHookBasePayload implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CLOUD_EVENT_VERSION = "cloudEventVersion";
    private String cloudEventVersion;

    public static final String JSON_PROPERTY_CONTENT_TYPE = "contentType";
    private String contentType;

    public static final String JSON_PROPERTY_EVENT_ID = "eventId";
    private String eventId;

    public static final String JSON_PROPERTY_EVENT_TIME = "eventTime";
    private String eventTime;

    public static final String JSON_PROPERTY_EVENT_TYPE_VERSION = "eventTypeVersion";
    private String eventTypeVersion;

    public InlineHookBasePayload() {
    }

    public InlineHookBasePayload cloudEventVersion(String cloudEventVersion) {

        this.cloudEventVersion = cloudEventVersion;
        return this;
    }

    /**
     * The inline hook cloud version
     *
     * @return cloudEventVersion
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "0.1", value = "The inline hook cloud version")
    @JsonProperty(JSON_PROPERTY_CLOUD_EVENT_VERSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getCloudEventVersion() {
        return cloudEventVersion;
    }

    @JsonProperty(JSON_PROPERTY_CLOUD_EVENT_VERSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCloudEventVersion(String cloudEventVersion) {
        this.cloudEventVersion = cloudEventVersion;
    }

    public InlineHookBasePayload contentType(String contentType) {

        this.contentType = contentType;
        return this;
    }

    /**
     * The inline hook request header content
     *
     * @return contentType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "application/JSON", value = "The inline hook request header content")
    @JsonProperty(JSON_PROPERTY_CONTENT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getContentType() {
        return contentType;
    }

    @JsonProperty(JSON_PROPERTY_CONTENT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setContentType(String contentType) {
        this.contentType = contentType;
    }

    public InlineHookBasePayload eventId(String eventId) {

        this.eventId = eventId;
        return this;
    }

    /**
     * The individual inline hook request ID
     *
     * @return eventId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "3o9jBzq1SmOGmmsDsqyyeQ", value = "The individual inline hook request ID")
    @JsonProperty(JSON_PROPERTY_EVENT_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getEventId() {
        return eventId;
    }

    @JsonProperty(JSON_PROPERTY_EVENT_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEventId(String eventId) {
        this.eventId = eventId;
    }

    public InlineHookBasePayload eventTime(String eventTime) {

        this.eventTime = eventTime;
        return this;
    }

    /**
     * The time the inline hook request was sent
     *
     * @return eventTime
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "2020-01-17T21:23:56.000Z", value = "The time the inline hook request was sent")
    @JsonProperty(JSON_PROPERTY_EVENT_TIME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getEventTime() {
        return eventTime;
    }

    @JsonProperty(JSON_PROPERTY_EVENT_TIME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEventTime(String eventTime) {
        this.eventTime = eventTime;
    }

    public InlineHookBasePayload eventTypeVersion(String eventTypeVersion) {

        this.eventTypeVersion = eventTypeVersion;
        return this;
    }

    /**
     * The inline hook version
     *
     * @return eventTypeVersion
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "1", value = "The inline hook version")
    @JsonProperty(JSON_PROPERTY_EVENT_TYPE_VERSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getEventTypeVersion() {
        return eventTypeVersion;
    }

    @JsonProperty(JSON_PROPERTY_EVENT_TYPE_VERSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEventTypeVersion(String eventTypeVersion) {
        this.eventTypeVersion = eventTypeVersion;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        InlineHookBasePayload inlineHookBasePayload = (InlineHookBasePayload) o;
        return Objects.equals(this.cloudEventVersion, inlineHookBasePayload.cloudEventVersion)
                && Objects.equals(this.contentType, inlineHookBasePayload.contentType)
                && Objects.equals(this.eventId, inlineHookBasePayload.eventId)
                && Objects.equals(this.eventTime, inlineHookBasePayload.eventTime)
                && Objects.equals(this.eventTypeVersion, inlineHookBasePayload.eventTypeVersion);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(cloudEventVersion, contentType, eventId, eventTime, eventTypeVersion);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class InlineHookBasePayload {\n");
        sb.append("    cloudEventVersion: ").append(toIndentedString(cloudEventVersion)).append("\n");
        sb.append("    contentType: ").append(toIndentedString(contentType)).append("\n");
        sb.append("    eventId: ").append(toIndentedString(eventId)).append("\n");
        sb.append("    eventTime: ").append(toIndentedString(eventTime)).append("\n");
        sb.append("    eventTypeVersion: ").append(toIndentedString(eventTypeVersion)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/InlineHookBasePayload.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * InlineHookBasePayload
 */
@JsonPropertyOrder({ InlineHookBasePayload.JSON_PROPERTY_CLOUD_EVENT_VERSION,
        InlineHookBasePayload.JSON_PROPERTY_CONTENT_TYPE, InlineHookBasePayload.JSON_PROPERTY_EVENT_ID,
        InlineHookBasePayload.JSON_PROPERTY_EVENT_TIME, InlineHookBasePayload.JSON_PROPERTY_EVENT_TYPE_VERSION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class InlineHookBasePayload implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CLOUD_EVENT_VERSION = "cloudEventVersion";
    private String cloudEventVersion;

    public static final String JSON_PROPERTY_CONTENT_TYPE = "contentType";
    private String contentType;

    public static final String JSON_PROPERTY_EVENT_ID = "eventId";
    private String eventId;

    public static final String JSON_PROPERTY_EVENT_TIME = "eventTime";
    private String eventTime;

    public static final String JSON_PROPERTY_EVENT_TYPE_VERSION = "eventTypeVersion";
    private String eventTypeVersion;

    public InlineHookBasePayload() {
    }

    public InlineHookBasePayload cloudEventVersion(String cloudEventVersion) {

        this.cloudEventVersion = cloudEventVersion;
        return this;
    }

    /**
     * The inline hook cloud version
     *
     * @return cloudEventVersion
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "0.1", value = "The inline hook cloud version")
    @JsonProperty(JSON_PROPERTY_CLOUD_EVENT_VERSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getCloudEventVersion() {
        return cloudEventVersion;
    }

    @JsonProperty(JSON_PROPERTY_CLOUD_EVENT_VERSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCloudEventVersion(String cloudEventVersion) {
        this.cloudEventVersion = cloudEventVersion;
    }

    public InlineHookBasePayload contentType(String contentType) {

        this.contentType = contentType;
        return this;
    }

    /**
     * The inline hook request header content
     *
     * @return contentType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "application/JSON", value = "The inline hook request header content")
    @JsonProperty(JSON_PROPERTY_CONTENT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getContentType() {
        return contentType;
    }

    @JsonProperty(JSON_PROPERTY_CONTENT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setContentType(String contentType) {
        this.contentType = contentType;
    }

    public InlineHookBasePayload eventId(String eventId) {

        this.eventId = eventId;
        return this;
    }

    /**
     * The individual inline hook request ID
     *
     * @return eventId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "3o9jBzq1SmOGmmsDsqyyeQ", value = "The individual inline hook request ID")
    @JsonProperty(JSON_PROPERTY_EVENT_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getEventId() {
        return eventId;
    }

    @JsonProperty(JSON_PROPERTY_EVENT_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEventId(String eventId) {
        this.eventId = eventId;
    }

    public InlineHookBasePayload eventTime(String eventTime) {

        this.eventTime = eventTime;
        return this;
    }

    /**
     * The time the inline hook request was sent
     *
     * @return eventTime
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "2020-01-17T21:23:56.000Z", value = "The time the inline hook request was sent")
    @JsonProperty(JSON_PROPERTY_EVENT_TIME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getEventTime() {
        return eventTime;
    }

    @JsonProperty(JSON_PROPERTY_EVENT_TIME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEventTime(String eventTime) {
        this.eventTime = eventTime;
    }

    public InlineHookBasePayload eventTypeVersion(String eventTypeVersion) {

        this.eventTypeVersion = eventTypeVersion;
        return this;
    }

    /**
     * The inline hook version
     *
     * @return eventTypeVersion
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "1", value = "The inline hook version")
    @JsonProperty(JSON_PROPERTY_EVENT_TYPE_VERSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getEventTypeVersion() {
        return eventTypeVersion;
    }

    @JsonProperty(JSON_PROPERTY_EVENT_TYPE_VERSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEventTypeVersion(String eventTypeVersion) {
        this.eventTypeVersion = eventTypeVersion;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        InlineHookBasePayload inlineHookBasePayload = (InlineHookBasePayload) o;
        return Objects.equals(this.cloudEventVersion, inlineHookBasePayload.cloudEventVersion)
                && Objects.equals(this.contentType, inlineHookBasePayload.contentType)
                && Objects.equals(this.eventId, inlineHookBasePayload.eventId)
                && Objects.equals(this.eventTime, inlineHookBasePayload.eventTime)
                && Objects.equals(this.eventTypeVersion, inlineHookBasePayload.eventTypeVersion);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(cloudEventVersion, contentType, eventId, eventTime, eventTypeVersion);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class InlineHookBasePayload {\n");
        sb.append("    cloudEventVersion: ").append(toIndentedString(cloudEventVersion)).append("\n");
        sb.append("    contentType: ").append(toIndentedString(contentType)).append("\n");
        sb.append("    eventId: ").append(toIndentedString(eventId)).append("\n");
        sb.append("    eventTime: ").append(toIndentedString(eventTime)).append("\n");
        sb.append("    eventTypeVersion: ").append(toIndentedString(eventTypeVersion)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
